@@ -7,9 +7,6 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
-    "Can not add feed: Unable to parse feed" : "Syötettä ei voi lisätä: syötteen jäsentäminen epäonnistui",
-    "Can not add feed: Exists already" : "Syötettä ei voi lisätä: se on jo olemassa",
-    "Articles without feed" : "Vailla syötettä olevat artikkelit",
     "News" : "Uutiset",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
