@@ -7,8 +7,6 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Token expirat sau aplicatie inactivă. Reîncarcă pagina!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Eroare server internă! Controlați fișierul data/nextcloud.log pentru mai multe informații!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Solecitare nereușită, Nexcloud este în întreţinere!",
-    "Can not add feed: Exists already" : "Nu pot adăuga fluxul: Deja există!",
-    "Articles without feed" : "Articole fără flux",
     "News" : "Noutăți",
     "Saved" : "Salvat",
     "Download" : "Descarcă",
