@@ -2,8 +2,6 @@
 
 namespace OCA\News\Command\Config;
 
-use OCA\News\Db\Feed;
-use OCA\News\Service\FeedServiceV2;
 use OCA\News\Service\FolderServiceV2;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Input\InputArgument;
@@ -27,6 +25,8 @@ class FolderAdd extends Command
 
     /**
      * Configure command
+     *
+     * @return void
      */
     protected function configure()
     {
