@@ -56,11 +56,11 @@ class ItemMapperV2 extends NewsMapperV2
                 ->innerJoin('items', FeedMapperV2::TABLE_NAME, 'feeds', 'items.feed_id = feeds.id')
                 ->where('feeds.user_id = :user_id')
                 ->andWhere('deleted_at = 0')
-                ->setParameter(':user_id', $userId, IQueryBuilder::PARAM_STR);
+                ->setParameter('user_id', $userId, IQueryBuilder::PARAM_STR);
 
         foreach ($params as $key => $value) {
             $builder->andWhere("${key} = :${key}")
-                    ->setParameter(":${key}", $value);
+                    ->setParameter($key, $value);
         }
 
         return $this->findEntities($builder);
@@ -90,8 +90,8 @@ class ItemMapperV2 extends NewsMapperV2
             ->where('feeds.user_id = :user_id')
             ->andWhere('items.id = :item_id')
             ->andWhere('deleted_at = 0')
-            ->setParameter(':user_id', $userId, IQueryBuilder::PARAM_STR)
-            ->setParameter(':item_id', $id, IQueryBuilder::PARAM_STR);
+            ->setParameter('user_id', $userId, IQueryBuilder::PARAM_STR)
+            ->setParameter('item_id', $id, IQueryBuilder::PARAM_STR);
 
         return $this->findEntity($builder);
     }
@@ -102,7 +102,7 @@ class ItemMapperV2 extends NewsMapperV2
      * @param int    $feedId   ID of the feed
      * @param string $guidHash hash to find with
      *
-     * @return Item|Entity
+     * @return Item
      *
      * @throws DoesNotExistException
      * @throws MultipleObjectsReturnedException
@@ -114,19 +114,24 @@ class ItemMapperV2 extends NewsMapperV2
             ->from($this->tableName)
             ->andWhere('feed_id = :feed_id')
             ->andWhere('guid_hash = :guid_hash')
-            ->setParameter(':feed_id', $feedId, IQueryBuilder::PARAM_INT)
-            ->setParameter(':guid_hash', $guidHash, IQueryBuilder::PARAM_STR);
+            ->setParameter('feed_id', $feedId, IQueryBuilder::PARAM_INT)
+            ->setParameter('guid_hash', $guidHash, IQueryBuilder::PARAM_STR);
 
         return $this->findEntity($builder);
     }
 
+    /**
+     * @param int $feedId
+     *
+     * @return array
+     */
     public function findAllForFeed(int $feedId): array
     {
         $builder = $this->db->getQueryBuilder();
         $builder->addSelect('*')
             ->from($this->tableName)
             ->andWhere('feed_id = :feed_id')
-            ->setParameter(':feed_id', $feedId, IQueryBuilder::PARAM_INT);
+            ->setParameter('feed_id', $feedId, IQueryBuilder::PARAM_INT);
 
         return $this->findEntities($builder);
     }
@@ -134,20 +139,68 @@ class ItemMapperV2 extends NewsMapperV2
     /**
      * Delete items from feed that are over the max item threshold
      *
-     * TODO: Implement
+     * @param int  $threshold    Deletion threshold
+     * @param bool $removeUnread If unread articles should be removed
      *
-     * @param int $threshold Deletion threshold
+     * @return int|null Removed items
+     *
+     * @throws \Doctrine\DBAL\Exception|\OCP\DB\Exception
      */
-    public function deleteOverThreshold(int $threshold)
+    public function deleteOverThreshold(int $threshold, bool $removeUnread = false): ?int
     {
-        $builder = $this->db->getQueryBuilder();
+        $feedQb = $this->db->getQueryBuilder();
+        $feedQb->select('feed_id', $feedQb->func()->count('*', 'itemCount'))
+               ->selectAlias($feedQb->func()->max('feeds.articles_per_update'), 'articlesPerUpdate')
+               ->from($this->tableName, 'items')
+               ->innerJoin('items', FeedMapperV2::TABLE_NAME, 'feeds', 'items.feed_id = feeds.id')
+               ->groupBy('feed_id');
 
-        $query = $builder->addSelect('COUNT(*)')
-                         ->from($this->tableName)
-                         ->groupBy('feed_id')
-                         ->where('');
+        $feeds = $this->db->executeQuery($feedQb->getSQL())
+                          ->fetchAll(FetchMode::ASSOCIATIVE);
 
-        return $this->db->executeQuery($query)->fetch(FetchMode::ASSOCIATIVE);
+        if ($feeds === []) {
+            return null;
+        }
+
+        $rangeQuery = $this->db->getQueryBuilder();
+        $rangeQuery->select('id')
+            ->from($this->tableName)
+            ->where('feed_id = :feedId')
+            ->andWhere('starred = false')
+            ->orderBy('updated_date', 'DESC');
+
+        if ($removeUnread === false) {
+            $rangeQuery->andWhere('unread = false');
+        }
+
+        $total_items = [];
+        foreach ($feeds as $feed) {
+            if ($feed['itemCount'] < $threshold) {
+                continue;
+            }
+
+            $rangeQuery->setFirstResult(max($threshold, $feed['articlesPerUpdate']));
+
+            $items = $this->db->executeQuery($rangeQuery->getSQL(), ['feedId' => $feed['feed_id']])
+                              ->fetchAll(FetchMode::COLUMN);
+
+            $total_items = array_merge($total_items, $items);
+        }
+
+        $deleteQb = $this->db->getQueryBuilder();
+        $deleteQb->delete($this->tableName)
+                 ->where('id IN (?)');
+
+        $affected_rows = 0;
+        // split $total_items into multiple chunks because of the parameter limit
+        foreach (array_chunk($total_items, NewsMapperV2::PDO_PARAMS_LIMIT) as $items_chunk) {
+            $affected_rows += $this->db->executeUpdate(
+                $deleteQb->getSQL(),
+                [$items_chunk],
+                [IQueryBuilder::PARAM_INT_ARRAY]
+            );
+        }
+        return $affected_rows;
     }
 
     /**
